-- Shorthand for languages
local en = Turbine.Language.English;
local fr = Turbine.Language.French;
local de = Turbine.Language.German;
local ru = Turbine.Language.Russian;

local text = {};

-- Hello message that appears when plugin is loaded
text.HelloMessage = {
    [en] = "<u><rgb=#DAA520>Class Trait Points Checklist v<version>, by Thurallor</rgb></u>";
    [de] = "<u><rgb=#DAA520>Checkliste Klasseneigenschaftspunkte v<version> von Thurallor</rgb></u>";
    [fr] = "<u><rgb=#DAA520>Liste des Points de Traits de Classe v<version>, by Thurallor</rgb></u>";
    [ru] = "<u><rgb=#DAA520>Очки классовых талантов v<version>, автор Thurallor</rgb></u>";
};
text.TranslationHelpWanted = {
    [en] = "Some items (denoted by †) have been machine-translated.  If you can help with translations, please contact Thurallor.";
    [de] = "Einige Elemente (gekennzeichnet durch †) wurden maschinell übersetzt.  Wenn du uns bei Übersetzungen helfen möchtest, wende dich bitte an Thurallor.";
    [fr] = "Certains éléments (marqués par †) ont été traduits par machine.  Si vous pouvez nous aider avec les traductions, veuillez contacter Thurallor.";
    [ru] = "Тексты, отмеченные знаком †, были переведены с помощью машинного перевода. Если у Вас есть возможность помочь улучшить перевод то, пожалуйста, обратитесь к Thurallor.";
};
text.GoodbyeMessage = {
    [en] = "unloaded";
    [de] = "entladen";
    [fr] = "déchargé";
    [ru] = "выгружен";
};
text.PutsPrefix = {
    [en] = "<rgb=#DAA520>Class Trait Points Checklist:</rgb> ";
    [de] = "<rgb=#DAA520>Checkliste Klasseneigenschaftspunkte:</rgb> ";
    [fr] = "<rgb=#DAA520>Liste des Points de Traits de Classe :</rgb> ";
    [ru] = "<rgb=#DAA520>Очки классовых талантов:</rgb> ";
};
text.ShellCommand = {
    Command = {
        [en] = "ctpc";
        [de] = "kspc";
        [fr] = "lptc";
        [ru] = "ctpc";
    };
    Help = {
        [en] = "help";
        [de] = "hilfe";
        [fr] = "aide";
        [ru] = "help";
    };
    ToggleWindow = {
        [en] = "toggle window";
        [de] = "umschalt fenster";
        [fr] = "basculez fenêtre";
        [ru] = "toggle window";
    };
    ToggleIcon = {
        [en] = "toggle icon";
        [de] = "umschalt symbol";
        [fr] = "basculez icône";
        [ru] = "toggle icon";
    };
    GetHelp = {
        [en] = "Commands for Class Trait Points Checklist:\n" ..
               "   /ctpc toggle window -- show or hide the main window\n" ..
               "   /ctpc toggle icon -- show or hide the icon\n";
        [de] = "Befehle für Checkliste Klasseneigenschaftspunkte:\n" ..
               "   /kspc umschalt fenster -- das Hauptfenster ein- oder ausblenden\n" ..
               "   /kspc umschalt symbol -- das Symbol ein- oder ausblenden\n";
        [fr] = "Commandes pour Liste des Points de Traits de Classe :\n" ..
               "   /lptc basculez fenêtre -- afficher ou masquer la fenêtre principale\n" ..
               "   /lptc basculez icône -- afficher ou masquer l'icône\n";
        [ru] = "Команды для плагина Очки классовых талантов:\n" ..
               "   /ctpc toggle window -- показать или скрыть окно плагина\n" ..
               "   /ctpc toggle icon -- показать или скрыть иконку плагина\n";
    };
    GetShortHelp = {
        [en] = "/ctpc toggle < window | icon >";
        [de] = "/kspc umschalt < fenster | symbol >";
        [fr] = "/lptc basculez < fenêtre | icône >";
        [ru] = "/ctpc toggle < window | icon >";
    };
    InvalidArguments = {
        [en] = "Invalid arguments";
        [de] = "Ungültige Argumente";
        [fr] = "Arguments non valables";
        [ru] = "Неверные аргументы";
    };
};


-- Main Checklist window
text.ChecklistWindow = {
    Title = {
        [en] = "Class Trait Points Checklist";
        [de] = "Checkliste Klasseneigenschaftspunkte";
        [fr] = "Liste des Points de Traits de Classe";
        [ru] = "Очки классовых талантов";
    };
    Description = {
        [en] = "For a <class> at level <level>, the following Class Trait Points may be earned:";
        [de] = "Für die Klasse <class> auf Stufe <level> können folgende Klasseneigenschaftspunkte erworben werden:";
        [fr] = "Pour un(e) <class> de niveau <level>, les points de traits de classe suivants peuvent être appris :";
        [ru] = "<class> <level> уровня может получить следующие очки классовых талантов:";
    };
    DescriptionHeight = {
        [en] = 1;
        [de] = 2;
        [fr] = 2;
        [ru] = 1;
    };
    PlayerLevel = {
        [en] = "Level <level>";
        [de] = "Stufe <level>";
        [fr] = "Niveau <level>";
        [ru] = "Уровень <level>";
    };
    PlayerClass = {
        Beorning = {
            [en] = "Beorning";
            [de] = "Beorninger";
            [fr] = "Béornide";
            [ru] = "Беорнинг";
        };
        Brawler = {
            [en] = "Brawler";
            [de] = "Schläger";
            [fr] = "Bagarreur";
            [ru] = "Задира";
        };
        Burglar = {
            [en] = "Burglar";
            [de] = "Schurke";
            [fr] = "Cambrioleur";
            [ru] = "Взломщик";
        };
        Captain = {
            [en] = "Captain";
            [de] = "Hauptmann";
            [fr] = "Capitaine";
            [ru] = "Рыцарь";
        };
        Champion = {
            [en] = "Champion";
            [de] = "Waffenmeister";
            [fr] = "Champion";
            [ru] = "Воитель";
        };
        Guardian = {
            [en] = "Guardian";
            [de] = "Wächter";
            [fr] = "Gardien";
            [ru] = "Страж";
        };
        Hunter = {
            [en] = "Hunter";
            [de] = "Jäger";
            [fr] = "Chasseur";
            [ru] = "Охотник";
        };
        LoreMaster = {
            [en] = "Lore-master";
            [de] = "Kundiger";
            [fr] = "Maître du Savoir";
            [ru] = "Хранитель мудрости";
        };
        Minstrel = {
            [en] = "Minstrel";
            [de] = "Barde";
            [fr] = "Ménestrel";
            [ru] = "Менестрель";
        };
        RuneKeeper = {
            [en] = "Rune-keeper";
            [de] = "Runenbewahrer";
            [fr] = "Gardien des Runes";
            [ru] = "Хранитель рун";
        };
        Warden = {
            [en] = "Warden";
            [de] = "Hüter";
            [fr] = "Sentinelle";
            [ru] = "Защитник";
        };
    };
    DeedLogSections = {
        Class = {
            [en] = "Class";
            [de] = "Klasse";
            [fr] = "Classe";
            [ru] = "Класс";
        };
        Epic = {
            [en] = "Epic";
            [de] = "Epos";
            [fr] = "Epique";
            [ru] = "Эпос";
        };
        Gondor = {
            [en] = "Gondor";
            [de] = "Gondor";
            [fr] = "Gondor";
            [ru] = "Гондор";
        };
        OldAnorien = {
            [en] = "Old Anórien";
            [de] = "Alt-Anórien";
            [fr] = "Ancien Anórien";
            [ru] = "Старый Анориен";
        };
    };
    QuestLogSections = {
        Kingstead = {
            [en] = "Kingstead";
            [de] = "Königsstatt";
            [fr] = "Terre-du-Roi";
            [ru] = "Королевские земли";
        };
        Eastfold = {
            [en] = "Eastfold";
            [de] = "Ostfold";
            [fr] = "Estfold";
            [ru] = "Восточная марка";
        };
        Broadacres = {
            [en] = "Broadacres";
            [de] = "Weite Mark";
            [fr] = "Grands-Arpents";
            [ru] = "Широкие поля";
        };
        Stonedeans = {
            [en] = "Stonedeans";
            [de] = "Felsensenke";
            [fr] = "Pierreval";
            [ru] = "Каменные балки";
        };
        Westfold = {
            [en] = "Westfold";
            [de] = "Westfold";
            [fr] = "Ouestfolde";
            [ru] = "Западная марка";
        };
        RingloVale = {
            [en] = "Central Gondor: Ringló Vale";
            [de] = "Zentrum Gondor: Ringlótal";
            [fr] = "Centre du Gondor : Val de Ringló";
            [ru] = "Центральный Гондор: Долина Рингло";
        };
        DorEnErnil = {
            [en] = "Central Gondor: Dor-en-Ernil";
            [de] = "Zentrum Gondor: Dor-en-Ernil";
            [fr] = "Centre du Gondor : Dor-En-Ernil";
            [ru] = "Центральный Гондор: Дор-эн-Эрнил";
        };
        LowerLebennin = {
            [en] = "Central Gondor: Lower Lebennin";
            [de] = "Zentrum Gondor: Nieder Lebennin";
            [fr] = "Centre du Gondor : Bas Lebennin";
            [ru] = "Центральный Гондор: Нижний Лебеннин";
        };
        Pelargir = {
            [en] = "Central Gondor: Pelargir";
            [de] = "Zentrum Gondor: Pelargir";
            [fr] = "Centre du Gondor : Pelargir";
            [ru] = "Центральный Гондор: Пеларгир";
        };
        AshesAndStars = {
            [en] = "Ashes and Stars";
            [de] = "Asche und Sterne";
            [fr] = "Cendres et Etoiles";
            [ru] = "Пепел и звезды";
        };
        TheDawnlessDay = {
            [en] = "Epic - Vol. IV, Book 2: The Dawnless Day";
            [de] = "Epos - Band IV, Buch 2: Tag ohne Morgen";
            [fr] = "Epique - Vol. IV, Livre 2 : Une journée sans aube";
            [ru] = "Эпос - том IV, книга 2: День без рассвета";
        };
        SiegeOfTheWhiteCity = {
            [en] = "Epic - Vol. IV, Book 4: Siege of the White City";
            [de] = "Epos - Band IV, Buch 4: Belagerung der Weisen Stadt";
            [fr] = "Epique - Vol. IV, Livre 4 : Le siège de la Cité blanche";
            [ru] = "Эпос - том IV, книга 4: Осада Белого города";
        };
        TheBlackGate = {
            [en] = "Epic - Vol. IV, Book 8: The Black Gate";
            [de] = "Epos - Band IV, Buch 8: Das Schwarze Tor";
            [fr] = "Epique - Vol. IV, Livre 8 : La Porte noire";
            [ru] = "Эпос - том IV, книга 8: Черные Врата";
        };
        TheRingOfPower = {
            [en] = "Epic - Vol. IV, Book 9: The Ring of Power";
            [de] = "Epos - Band IV, Buch 9: Der Ring der Macht";
            [fr] = "Epique - Vol. IV, Livre 9 : L'Anneau de pouvoir";
            [ru] = "Эпос - Том IV, книга 9: Кольцо Всевластья";
        };
        BlackBookOfMordor = {
            [en] = "The Black Book of Mordor";
            [de] = "Das Schwarze Buch von Mordor";
            [fr] = "Le Livre noir du Mordor";
            [ru] = "Черная Книга Мордора";
        };
        LegacyOfDurin = {
            [en] = "The Legacy of Durin and the Trials of the Dwarves";
            [de] = "Das Vermächtnis von Durins Volk & Die Prüfung der Zwerge";
            [fr] = "L'heritage de Durin et les epreuves des Nains";
            [ru] = "Наследие Дарина и испытания гномов";
        };
        ATimeOfCelebration = {
            [en] = "Epic - Vol. V. Book 1: A Time of Celebration";
            [de] = "Epos - Band V. Buch 1: Eine Zeit für Feierlichkeiten";
            [fr] = "Epique - Vol. V, Livre 1 : Un moment de fete";
            [ru] = "Эпос - том V, книга 1: Время праздника";
        };
        BloodOfAzog = {
            [en] = "Blood of Azog";
            [de] = "Azogs Blut";
            [fr] = "Sang d'Azog";
            [ru] = "Кровь Азога";
        };
    };
    Items = {
        AriaOfTheValar = {
            Desc = {
                [en] = "(<points> points) Aria of the Valar - 105";
                [de] = "(<points> Punkte) Arie der Valar - 105";
                [fr] = "(<points> points) Aria des Valar - 105";
                [ru] = "(<points> очка) Ария Валар - 105";
            };
            Help = {
                [en] = "You received these Class Trait Points after purchasing the Aria of the Valar and using the included items:\n   (54 points) Aria of the Valar\n   (<points> points) Class Deed Tome - <class>\n   (3 points) Deed Tome - Rohan Quests\n   (4 points) Deed Tome - Gondor Quests";
                [de] = "Du hast diesen Klasseneigenschaftpunkt erhalten, nachdem du die Arie der Valar gekauft und die enthaltenen Gegenstände verwendet hast:\n   (54 Punkte) Arie der Valar\n   (<points> Punkte) Klassentat-Schrift - <class>\n   (3 Punkte) Tat-Schrift - Aufgaben von Rohan\n   (4 Punkte) Tat-Schrift - Aufgaben von Gondor";
                [fr] = "Vous recevez ces points de traits de classes après l'achat du pack Aria des Valar et que vous utilisez les objets inclus :\n   (54 points) Aria des Valar\n   (<points> points) Tome des prouesses de classe - <class>\n   (3 points) Tome des prouesses - Quêtes du Rohan\n   (4 points) Tome des prouesses - Quêtes du Gondor";
                [ru] = "Очки классовых талантов при использовании Арии Валар, включая следующие предметы:\n   (54 очка) Ария Валар\n   (<points> очка) Фолиант классовых деяний - <class>\n   (3 очка) Фолиант деяний - Задания Рохана\n   (4 очка) Фолиант деяний - Задания Гондора";
            };
            Height = {
                [en] = 7;
                [de] = 7;
                [fr] = 7;
                [ru] = 7;
            };
        };
        ForReachingLevel = {
            Desc = {
                [en] = "For reaching Level <level>";
                [de] = "Für das Erreichen der Stufe <level>";
                [fr] = "Pour avoir atteint le niveau <level>";
                [ru] = "Персонаж <level> уровня";
            };
            Help = {
                [en] = "You received this Class Trait Point automatically when your character reached level <level>.";
                [de] = "Du erhältst einen Klasseneigenschaftspunkt, wenn deine Klasse die Stufe <level> erreicht hat.";
                [fr] = "Vous recevez automatiquement ce point de trait de classe lorsque votre personnage atteint le niveau <level>.";
                [ru] = "1 очко классовых талантов при достижении вашим персонажем <level> уровня.";
            };
            Height = {
                [en] = 1;
                [de] = 1;
                [fr] = 2;
                [ru] = 1;
            };
        };
        ClassDeeds = {
            Desc = {
                [en] = "For completing the deed: <name>";
                [de] = "Für das Abschließen der Tat: <name>";
                [fr] = "Pour avoir complété la prouesse : <name>";
                [ru] = "Деяние: <name>";
            };
            Help = {
                [en] = "This Class Trait Point is awarded when a deed is completed.  Open your Deed Log, select the “Class/Race/Epic” tab at the top, and the “<section>” tab at the bottom.  If the deed is not listed there, you may need to perform a skill or complete a quest to start it.";
                [de] = "Dieser Klasseneigenschaftspunkt wird beim Vollenden einer Tat erzielt.  Öffne dazu dein Buch der Taten und gehe auf den Tab „Klasse/Rasse/Epos“ und dann unten auf den Tab „<section>“.  Sollte hier keine Tat gelistet sein, dann musst du möglicherweise einmal einen Skill ausführen, oder eine Aufgabe abschließen, um diese dann zu erhalten. Bücher können beim Ausbilder gekauft werden. Mehr Infos dazu im Lotro Wiki:";
                [fr] = "Ce point de trait de classe est obtenu quand une prouesse est complétée. Ouvrez Le journal des prouesses, selectionnez l'onglet « Classe/Race/Epique » en haut du journal et l'onglet « <section> » qui est en bas. Si la prouesse n'est pas listée alors vous devez compléter une tache ou une quête pour la démarrer.";
                [ru] = "1 очко классовых талантов при выполнении деяния. Откройте Журнал деяний, раздел “Класс/раса/эпос” и вкладку “<section>”. Если деяния нет в списке, то Вам необходимо применить определенное умение или выполнить  дополнительное задание для его получения.";
            };
            Height = {
                [en] = 4;
                [de] = 6;
                [fr] = 5;
                [ru] = 5;
            };
            Tiered = {
                [en] = "Class Deeds - Tier <tier>";
                [de] = "Klassentaten - Stufe <tier>";
                [fr] = "Prouesses de Classe - Tier <tier>";
                [ru] = "Классовые деяния: уровень <tier>";
            };
            MinesOfMoria = {
                [en] = "The Mines of Moria";
                [de] = "Die Minen von Moria";
                [fr] = "Les Mines de la Moria";
                [ru] = "Копи Мории";
            };
            Beorning1 = {
                [en] = "A Hobbit's Holiday";
                [de] = "Ein Hobbit-Feiertag (Buch)";
                [fr] = "Vacances d'un Hobbit";
                [ru] = "Странствие хоббита";
            };
            Beorning2 = {
                [en] = "A Study of the Skin-changer";
                [de] = "Eine Studie der Gestaltenwandler (Buch)";
                [fr] = "Une étude d'un changeur de peau";
                [ru] = "Изучение сменяющих обличье";
            };
            Beorning3 = {
                [en] = "Genealogy of the Beornings";
                [de] = "Genealogie des Beorningers (Buch)";
                [fr] = "Généalogie des Beornides";
                [ru] = "Родословная беорнингов";
            };
            Brawler1 = {
                [en] = "Martial Movement";
                [de] = "Bewegung im Kampf";
                [fr] = "Déplacement martial";
                [ru] = "Техника движения в бою";
            };
            Brawler2 = {
                [en] = "Knowledge of Kicks";
                [de] = "Das Wissen der Tritte";
                [fr] = "Connaissance des coups de pied";
                [ru] = "Наука о пинках";
            };
            Brawler3 = {
                [en] = "The Art of the Perfect Punch";
                [de] = "Die Kunst des perfekten Schlags";
                [fr] = "L'Art du coup de poing parfait";
                [ru] = "Искусство идеального удара";
            };
            Burglar1 = {
                [en] = "Knee-breaker's Manual";
                [de] = "Lehrbuch des Kniebrechers (Buch)";
                [fr] = "Manuel de brise-rotule";
                [ru] = "Записки Костолома";
            };
            Burglar2 = {
                [en] = "The Book of Knives";
                [de] = "Das Buch der Messer (Buch)";
                [fr] = "Livre des couteaux";
                [ru] = "Книга ножей";
            };
            Burglar3 = {
                [en] = "The Expert's Guide to Dirty Fighting";
                [de] = "Der heimtückische Kampf - Ein Leitfaden für Experten (Buch)";
                [fr] = "Guide de l'Expert en combat irrégulier";
                [ru] = "Наставления по бесчестному бою";
            };
            Burglar4 = {
                [en] = "The Path of the Mischief-maker";
                [de] = "Der Pfad des Erzschelms (Questreihe)";
                [fr] = "La voie de l'espièglerie";
                [ru] = "Путь Хитреца";
            };
            Burglar5 = {
                [en] = "A Guide to the Quiet Knife";
                [de] = "Das Schweigen der Messer (Moria-Buch)";
                [fr] = "Le guide du poignard silencieux";
                [ru] = "Наставление по бесшумным ножам";
            };
            Captain1 = {
                [en] = "The Book of Oaths";
                [de] = "Das Buch der Eidschwüre (Buch)";
                [fr] = "Le livre des serments";
                [ru] = "Книга клятв";
            };
            Captain2 = {
                [en] = "The Candle's Flame";
                [de] = "Der zündende Funke (Buch)";
                [fr] = "La flamme de la Bougie";
                [ru] = "Пламя свечи";
            };
            Captain3 = {
                [en] = "The Treatise of Valour";
                [de] = "Abhandlung über den Heldenmut (Buch)";
                [fr] = "Le traité du courage";
                [ru] = "Трактат о доблести";
            };
            Captain4 = {
                [en] = "The Path of the Healing Hands";
                [de] = "Der Pfad der heilenden Hände (Questreihe)";
                [fr] = "La voie des mains guérisseuses";
                [ru] = "Путь Исцеляющих ладоней";
            };
            Captain5 = {
                [en] = "Master of the Charge";
                [de] = "Meisterhafte Befehlsführung (Moria-Buch)";
                [fr] = "La maîtrise de la charge";
                [ru] = "Мастер атаки";
            };
            Champion1 = {
                [en] = "The Artisan Blade";
                [de] = "Die Kunst der Klingenführung (Buch)";
                [fr] = "La lame de l'artisant";
                [ru] = "Изящество клинка";
            };
            Champion2 = {
                [en] = "The Joy of Battle";
                [de] = "Ode an die Schlacht (Buch)";
                [fr] = "La beauté du combat";
                [ru] = "Радость битвы";
            };
            Champion3 = {
                [en] = "The Tome of Swords";
                [de] = "Die Schrift der Schwerter (Buch)";
                [fr] = "Le tome des épées";
                [ru] = "Рукопись о мечах";
            };
            Champion4 = {
                [en] = "The Path of the Martial Champion";
                [de] = "Der Pfad des Meisters der Kampfkunst (Questreihe)";
                [fr] = "La voie du champion martial";
                [ru] = "Путь Доблестного воителя";
            };
            Champion5 = {
                [en] = "The Boiling Rage";
                [de] = "Zornentbrannt (Moria-Buch)";
                [fr] = "Brulure controlée";
                [ru] = "Кипящий гнев";
            };
            Guardian1 = {
                [en] = "A Shield-maiden's Song";
                [de] = "Das Lied einer Schildmaid (Buch)";
                [fr] = "Chant d'une jeune fille au bouclier";
                [ru] = "Песнь девы-защитницы";
            };
            Guardian2 = {
                [en] = "The Best Defence";
                [de] = "Die beste Verteidigung (Buch)";
                [fr] = "La meilleure défense";
                [ru] = "Наилучшая защита";
            };
            Guardian3 = {
                [en] = "The Final Word";
                [de] = "Das letzte Wort (Buch)";
                [fr] = "Le mot final";
                [ru] = "Нерушимое слово";
            };
            Guardian4 = {
                [en] = "The Path of Freedom's Defender";
                [de] = "Der Pfad des Verteidigers der Freien (Questreihe)";
                [fr] = "La voie du défenseur de la liberté";
                [ru] = "Путь Защитника свободы";
            };
            Guardian5 = {
                [en] = "A Keen Blade";
                [de] = "Eine kühne Klinge (Moria-Buch)";
                [fr] = "Une lame acérée";
                [ru] = "Острый клинок";
            };
            Hunter1 = {
                [en] = "A Shot in the Dark";
                [de] = "Ein Schuss ins Blaue (Buch)";
                [fr] = "Un coup dans le noir";
                [ru] = "Выстрел во тьме";
            };
            Hunter2 = {
                [en] = "The Furthest Charge";
                [de] = "Angriff aus der Ferne (Buch)";
                [fr] = "La charge lointaine";
                [ru] = "Глубокий прорыв";
            };
            Hunter3 = {
                [en] = "The Way of the Hunter";
                [de] = "Die Methoden des Jägers (Buch)";
                [fr] = "Livre des chasseurs";
                [ru] = "Путь охотника";
            };
            Hunter4 = {
                [en] = "The Path of the Foe-trapper";
                [de] = "Der Pfad des Fallenstellers (Questreihe)";
                [fr] = "La voie du piégeur";
                [ru] = "Путь Капканщика";
            };
            Hunter5 = {
                [en] = "The Jolly Hunter";
                [de] = "Der fröhliche Jäger (Moria-Buch)";
                [fr] = "Le chasseur jovial";
                [ru] = "Веселый охотник";
            };
            LoreMaster1 = {
                [en] = "Of Leaf and Twig";
                [de] = "Von Blättern und Zweigen (Buch)";
                [fr] = "Des feuilles et des brindilles";
                [ru] = "О ветвях и листьях";
            };
            LoreMaster2 = {
                [en] = "The Book of Beasts";
                [de] = "Das Buch der Kreaturen (Buch)";
                [fr] = "Livre des monstres";
                [ru] = "Книга зверей";
            };
            LoreMaster3 = {
                [en] = "Lore of the Blade";
                [de] = "Die Klingenkunde (Buch)";
                [fr] = "La science de l'épée";
                [ru] = "Наука клинка";
            };
            LoreMaster4 = {
                [en] = "The Path of the Ancient Master";
                [de] = "Der Pfad des uralten Meisters (Questreihe)";
                [fr] = "La voie de l'ancien maître";
                [ru] = "Путь Магистра древних знаний";
            };
            LoreMaster5 = {
                [en] = "The Book of Nature";
                [de] = "Das Buch der Natur (Moria-Buch)";
                [fr] = "Le livre de la nature";
                [ru] = "Книга природы";
            };
            Minstrel1 = {
                [en] = "Melodies of the Valar";
                [de] = "Melodien der Valar (Buch)";
                [fr] = "Mélodies des Valar";
                [ru] = "Мелодии Валар";
            };
            Minstrel2 = {
                [en] = "The Rising Chord";
                [de] = "Der Erhabene Akkord (Buch)";
                [fr] = "L'accord montant";
                [ru] = "Живительный аккорд";
            };
            Minstrel3 = {
                [en] = "Valour's Marches";
                [de] = "Die Märsche der Tapferen (Buch)";
                [fr] = "Les marches du courage";
                [ru] = "Безумству храбрых";
            };
            Minstrel4 = {
                [en] = "The Path of the Resolve-watcher";
                [de] = "Der Pfad des Wächters der Entschlossenheit (Questreihe)";
                [fr] = "La voie du soigneur";
                [ru] = "Путь Хранителя решимости";
            };
            Minstrel5 = {
                [en] = "The Verses of the North";
                [de] = "Verse des Nordens (Moria-Buch)";
                [fr] = "Couplets du Nord";
                [ru] = "Висы севера";
            };
            RuneKeeper1 = {
                [en] = "Thunder and Flame";
                [de] = "Donner und Flamme (Buch)";
                [fr] = "Foudre et flammes";
                [ru] = "Гром и пламя";
            };
            RuneKeeper2 = {
                [en] = "Whispers in the Dark";
                [de] = "Geflüster in der Dunkelheit (Buch)";
                [fr] = "Murmures dans les ténébres";
                [ru] = "Шепот во тьме";
            };
            RuneKeeper3 = {
                [en] = "Golu o Maeth";
                [de] = "Golu o Maeth (Buch)";
                [fr] = "Golu o Maeth";
                [ru] = "Голу о Маэт";
            };
            RuneKeeper4 = {
                [en] = "The Path of the Rune of Restoration";
                [de] = "Der Pfad der Rune der Wiederherstellung (Questreihe)";
                [fr] = "La voie de la rune de restauration";
                [ru] = "Путь Рун восстановления";
            };
            RuneKeeper5 = {
                [en] = "On the Patterns of Wind and Rain";
                [de] = "Über die Strukturen von Wind und Regen (Moria-Buch)";
                [fr] = "Etude des vents et précipitations";
                [ru] = "О ветрах и дождях";
            };
            Warden1 = {
                [en] = "The Watch Against the Night";
                [de] = "Wacht gegen die Nacht (Buch)";
                [fr] = "Sentinelles contre les ténébres";
                [ru] = "Против тьмы ночной";
            };
            Warden2 = {
                [en] = "Chieftains of the Dúnedain";
                [de] = "Anführer der Dúnedain (Buch)";
                [fr] = "Les chefs des Dunedain";
                [ru] = "Предводители дунаданов";
            };
            Warden3 = {
                [en] = "Bullroarer's Boy";
                [de] = "Der Sohn des Bullenrasslers (Buch)";
                [fr] = "Le fils du taureau mugissant";
                [ru] = "Сын Бандобраса";
            };
            Warden4 = {
                [en] = "The Path of the Masterful Fist";
                [de] = "Der Pfad der meisterlichen Faust (Questreihe)";
                [fr] = "La voie de la maîtrise du poing";
                [ru] = "Путь Искусного кулака";
            };
            Warden5 = {
                [en] = "The Path Less Trod";
                [de] = "Ein kaum beschrittener Pfad (Moria-Buch)";
                [fr] = "Les chemins de traverse";
                [ru] = "Неторная тропа";
            };
        };
        OtherDeeds = {
            Desc = {
                [en] = "For completing the deed: <name>";
                [de] = "Für das Abschließen der Tat: <name>";
                [fr] = "Pour avoir fini la prouesse : <name>";
                [ru] = "Деяние: <name>";
            };
            Help = {
                [en] = "This Class Trait Point is awarded when a deed is completed.  Open your Deed Log, select the “<tab>” tab at the top, and the “<section>” tab at the bottom.  If the deed is not listed there, you may need to complete a quest to start it.";
                [de] = "Dieser Klasseneigenschaftspunkt wird beim Abschließen einer Tat erworben.  Öffne dazu dein Buch der Taten, gehe auf den Tab „<tab>“ und wähle dort dann „<section>“ bei den unteren Tabs aus.  Sollte dir die Tat nicht aufgelistet werden, so musst du evtl. zuerst eine Quest abschließen.";
                [fr] = "Ce point de trait de classe est obtenu quand une prouesse est complétée. Ouvrez Le journal des prouesses, selectionnez l'onglet « <tab> » en haut du journal et l'onglet « <section> » qui est en bas. Si la prouesse n'est pas listée alors vous devez compléter une quête pour la démarrer.";
                [ru] = "1 очко классовых талантов были при выполнении деяния. Откройте Журнал деяний, раздел “<tab>” и вкладку “<section>”. Если деяния нет в списке, то Вам необходимо применить определенное умение или выполнить дополнительное задание для его получения.";
            };
            Height = {
                [en] = 4;
                [de] = 5;
                [fr] = 5;
                [ru] = 4;
            };
            OldAnorienQuests = {
                [en] = "Quests of Old Anórien";
                [de] = "Aufgaben von Alt-Anórien";
                [fr] = "Quêtes de l'Ancien Anórien";
                [ru] = "Задания Старого Анориена";
            };
            OldAnorienDeeds = {
                [en] = "Deeds of Old Anórien";
                [de] = "Taten von Alt-Anórien";
                [fr] = "Prouesses d'Ancien Anórien";
                [ru] = "Деяния Старого Анориена";
            };
        };
        ClassQuests = {
            Desc = {
                [en] = "For completing the class quest: <name>";
                [de] = "Für das Abschließen der Klassenaufgabe: <name>";
                [fr] = "Pour avoir complété la quête de classe : <name>";
                [ru] = "Классовое задание: <name>";
            };
            Help = {
                [en] = "This Class Trait Point is awarded when a quest is completed.  Open your Quest Log, tick the “Show Completed” box, and open the “<class>” quest group.  If the quest is not listed there, you may need to complete a prerequisite quest to start it.";
                [de] = "Dieser Klasseneigenschaftspunkt wird durch den Abschluss einer Aufgabe erworben.  Zum Überprüfen, ob du diese schon abgeschlossen hast, gehe wie folgt vor: Öffne deine Aufgabenliste, klicke dort auf „Abgeschlossene anzeigen“ und öffne dort die Aufgabenübersicht zu „<class>“. Wenn die Aufgabe dort nicht gelistet ist, so musst du evtl. zuerst eine vorherige Aufgabe abschließen.";
                [fr] = "Ce point de trait de classe est obtenu quand une quête est complétée. Ouvrez le journal des quêtes, cochez la boîte « Voir les quêtes terminées » et ouvrez le groupe de quêtes « <class> ». Si la quête n'est parti listée ici, vous n'avez pas complété une quête prérequise pour la démarrer.";
                [ru] = "1 очко классовых талантов за выполнение задания. Откройте Журнал заданий, отметьте “Завершенные задания”, и выберите группу заданий “<class>”. Если задание отсутствует в выбранном списке, то Вам необходимо выполнить дополнительное задание для его получения.";
            };
            Height = {
                [en] = 4;
                [de] = 6;
                [fr] = 5;
                [ru] = 5;
            };
            Beorning = {
                Quest1 = {
                    Name = {
                        [en] = "[15] The Speech of Animals";
                        [de] = "[15] Der Sprache der Tiere";
                        [fr] = "[15] Le langage des animaux";
                        [ru] = "[15] Язык зверей";
                    };
                    Bestower = {
                        [en] = "Clothar Sandheaver, in Adso's Camp, Bree-land: 29.3S, 56.7W";
                        [de] = "Clothar Sandheber, Arthurs Lager, Breeland: 29.3S, 56.7W";
                        [fr] = "Clothar, au camp d'Adso dans le pays de Bree : 29.3S, 56.7W";
                        [ru] = "Клотар Запескунс, Земли Бри-лагерь Адсо: 29.3S, 56.7W";
                    };
                };
                Quest2 = {
                    Name = {
                        [en] = "[30] Hatred of Bear and Man";
                        [de] = "[30] Der Hass von Mensch und Bär";
                        [fr] = "[30] La haine des ours et des hommes";
                        [ru] = "[30] Отступник";
                    };
                    Bestower = {
                        [en] = "Langhár, in Ost Guruth, Lone-lands: 31.4S, 29.3W";
                        [de] = "Langhár, Feste Guruth, Einsame Lande: 31.4S, 29.3W";
                        [fr] = "Langhár, à Ost Guruth dans les Terres Solitaires : 31.4S, 29.3W";
                        [ru] = "Лангхар, Пустоши-Ост Гурут: 31.4S, 29.3W";
                    };
                };
                Quest3 = {
                    Name = {
                        [en] = "[50] Grimbeorn's Challenge";
                        [de] = "[50] Grimbeorns Herausforderung";
                        [fr] = "[50] Le défi de Grimbeorn";
                        [ru] = "[50] Испытание Гримбеорна";
                    };
                    Bestower = {
                        [en] = "Sterkist, in Rivendell, Trollshaws: 29.9S, 4.7W";
                        [de] = "Sterkist, Bruchtal, Trollhöhen: 29.9S, 4.7W";
                        [fr] = "Sterkist, à Rivendell (Fondcombe) dans la Trouée des Trolls : 29.9S, 4.7W";
                        [ru] = "Стеркист, Троллистая пуща-Ривенделл: 29.9S, 4.7W";
                    };
                };
                Quest4 = {
                    Name = {
                        [en] = "[58] The Path Homeward";
                        [de] = "[58] Der Weg nach Hause";
                        [fr] = "[58] Le chemin du retour";
                        [ru] = "[58] Путь домой";
                    };
                    Bestower = {
                        [en] = "Varthmath, at the Orc-watch, Redhorn Lodes: 11.1S, 106.7W";
                        [de] = "Varthmath / Die Ork-Wacht, Rothorn-Adern: 11.1S, 106.7W";
                        [fr] = "Varthmath, au Guet de l'Orque (Moria), Filons du Rubicorne: 11.1S, 106.7W";
                        [ru] = "Вартмат, Мория-Багровые копи, Орочий дозор: 11.1S, 106.7W";
                    };
                };
            };
            Brawler = {
                Quest1 = {
                    Name = {
                        [en] = "[15] Threat of a Good Punch";
                        [de] = "[15] Ein drohender Schlag";
                        [fr] = "[15] La menace d'un bon coup de poing";
                        [ru] = "[15] Возможность хорошенько подраться";
                    };
                    Bestower = {
                        [en] = "Brom Hawksbeard, Bree-town Jail: 31.7S, 50.8W";
                        [de] = "Brom Falkenbart, Gefängnis von Bree: 31.7S, 50.8W";
                        [fr] = "Brom Barbe-de-faucon, Prison de Bree: 31.7S, 50.8W";
                        [ru] = "Бром Ястребиная Борода, Земли Бри-Тюрьма города Бри: 31.7S, 50.8W";
                    };
                };
                Quest2 = {
                    Name = {
                        [en] = "[30] The Melee in the Square";
                        [de] = "[30] Der Kampf auf dem Platz";
                        [fr] = "[30] Corps à corps sur la place publique";
                        [ru] = "[30] Драка на площади";
                    };
                    Bestower = {
                        [en] = "Brom Hawksbeard, Bree-town Jail, 31.7S, 50.8W";
                        [de] = "Brom Falkenbart, Gefängnis von Bree: 31.7S, 50.8W";
                        [fr] = "Brom Barbe-de-faucon, Prison de Bree: 31.7S, 50.8W";
                        [ru] = "Бром Ястребиная Борода, Земли Бри-Тюрьма города Бри: 31.7S, 50.8W";
                    };
                };
                Quest3 = {
                    Name = {
                        [en] = "[50] Brawling Lessons";
                        [de] = "[50] Lektionen im Faustkampf";
                        [fr] = "[50] L'art de la bagarre";
                        [ru] = "[50] Уроки кулачного боя";
                    };
                    Bestower = {
                        [en] = "Hunward at Trader's Wharf in Evendim: 21.4S, 61.5W";
                        [de] = "Hunward, Händlerkai, Evendim: 21.4S, 61.5W";
                        [fr] = "Hunward, Quai des marchands, Evendim: 21.4S, 61.5W";
                        [ru] = "Хунвард, Эвендим-Торговая пристань: 21.4S, 61.5W";
                    };
                };
                Quest4 = {
                    Name = {
                        [en] = "[58] A Drubbing in the Deep";
                        [de] = "[58] Ein Schlag in die Tiefe†";
                        [fr] = "[58] Une raclée dans les profondeurs†";
                        [ru] = "[58] Драка под землей";
                    };
                    Bestower = {
                        [en] = "via mail";
                        [de] = "per Post";
                        [fr] = "par courrier";
                        [ru] = "получение по почте";
                    };
                };
            };
            Burglar = {
                [en] = "A Lesson from Bilbo Baggins";
                [de] = "Bilbo Beutlins Lehrstunde";
                [fr] = "Une leçon de Bilbon Sacquet";
                [ru] = "Урок Бильбо Торбинса";
            };
            Captain = {
                [en] = "A Lesson from Boromir";
                [de] = "Boromirs Lehrstunde";
                [fr] = "Une leçon de Boromir";
                [ru] = "Урок Боромира";
            };
            Champion = {
                [en] = "A Lesson from Gimli";
                [de] = "Eine Lektion von Gimli";
                [fr] = "Une leçon de Gimli";
                [ru] = "Урок Гимли";
            };
            Guardian = {
                [en] = "A Lesson from Samwise Gamgee";
                [de] = "Eine Lektion von Samweis Gamdschie";
                [fr] = "Une leçon de Samsagace Gamegie";
                [ru] = "Урок Сэммиума Скромби";
            };
            Hunter = {
                [en] = "A Lesson from Legolas";
                [de] = "Eine Lektion von Legolas";
                [fr] = "Une leçon de Legolas";
                [ru] = "Урок Леголаса";
            };
            LoreMaster = {
                [en] = "A Lesson from Lord Elrond";
                [de] = "Fürst Elronds Lehrstunde";
                [fr] = "Une leçon de Seigneur Elrond";
                [ru] = "Урок владыки Элронда";
            };
            Minstrel = {
                [en] = "A Lesson from Lindir";
                [de] = "Lindirs Lehrstunde";
                [fr] = "Une leçon de Lindir";
                [ru] = "Урок Линдира";
            };
            RuneKeeper = {
                [en] = "Deep Secrets of Rune-craft";
                [de] = "Verborgene Geheimnisse der Runenkunde";
                [fr] = "Les secrets de l'art des runes";
                [ru] = "Тайны рунического ремесла";
            };
            Warden = {
                [en] = "Wisdom of the Wardens" ;
                [de] = "Die Weisheit der Hüter";
                [fr] = "La sagesse des sentinelles";
                [ru] = "Мудрость защитников";
            };
        };
        OtherQuests = {
            Help = {
                [en] = "This Class Trait Point is awarded when a quest is completed.  Open your Quest Log, tick the “Show Completed” box, and open the “<section>” quest group.  If the quest is not listed there, you may need to complete a prerequisite quest to start it.";
                [de] = "Dieser Klasseneigenschaftspunkt kann durch das Abschließen dieser Aufgabe erworben werden. Ob du diese bereits abgeschlossen hast, kannst du in deiner Aufgabenliste sehen.  Klicke in der Aufgabenliste auf „Abgeschlossene Aufgaben anzeigen“ und öffne dort den Reiter „<section>“.  Sollte die Aufgabe hier nicht gelistet sein, so kann es sein, dass du eine vorherige Aufgabe nicht erledigt hast.";
                [fr] = "Ce point de trait de classe est obtenu quand une quête est complétée. Ouvrez le journal des quêtes, cochez la boite « Voir les quêtes terminées » et ouvrez le groupe de quêtes « <section> ». Si la quête n'apparait pas vous devez compléter une quête prérequise pour la démarrer.";
				[ru] = "1 очко классовых талантов за выполнение задания. Откройте Журнал заданий, отметьте “Завершенные задания”, и выберите группу заданий “<section>”. Если в выбранном списке оно отсутствует, то Вам необходимо выполнить дополнительное задание для его получения.";
            };
            Desc = {
                [en] = "For completing the quest: <name>";
                [de] = "Für das Abschließen der Aufgabe: <name>";
                [fr] = "Pour avoir complété la quête : <name>";
				[ru] = "Задание: <name>";
            };
            Height = {
                [en] = 5;
                [de] = 7;
                [fr] = 5;
                [ru] = 5;
            };
            Quest1 = {
                Name = {
                    [en] = "The Road to Dunharrow";
                    [de] = "Der Weg nach Dunharg";
                    [fr] = "La route de Dunharrow";
                    [ru] = "Дорога в Дунхарроу";
                };
                Bestower = {
                    [en] = "Éowyn, in Edoras, Kingstead: 62.0S, 72.8W";
                    [de] = "Éowyn, in Edoras, Königsstatt: 62.0S 72.8W";
                    [fr] = "Éowyn, dans Edoras, Terre-du-Roi : 62.0S, 72.8W";
                    [ru] = "Эовин, Западный Рохан-Эдорас: 62.0S, 72.8W";
                };
            };
            Quest2 = {
                Name = {
                    [en] = "All Roads Lead Back to Aldburg";
                    [de] = "Alle Straßen führen nach Aldburg zurück";
                    [fr] = "Toutes les routes mènent à Aldburg";
                    [ru] = "Все дороги ведут в Альдбург";
                };
                Bestower = {
                    [en] = "Cútha, at the Mead Hall in Beaconwatch, Eastfold: 69.8S, 56.8W";
                    [de] = "Cútha, in der Met-Halle in Leuchtfeuerwacht, Ostfold: 69.8S, 56.8W";
                    [fr] = "Cútha, à la salle des banquets dans Veillefeu, Estfold : 69.8S, 56.8W";
                    [ru] = "Кута, Западный Рохан-Восточная марка, Меринг (Пиршественный зал): 69.8S, 56.8W";
                };
            };
            Quest3 = {
                Name = {
                    [en] = "The Broadacres Betrayed";
                    [de] = "Betrug der Weiten Mark";
                    [fr] = "Les Grands-Arpents trahis";
                    [ru] = "Предатель Широких полей";
                };
                Bestower = {
                    [en] = "Torferth, at Tordag's Camp in Broadacres: 45.7S, 72.1W";
                    [de] = "Torferth, in Tordags Lager, Weite Mark: 45.7S 72.1W";
                    [fr] = "Torferth, au camp de Tordag dans Les Grands-Arpents : 45.7S, 72.1W";
                    [ru] = "Торферт, Западный Рохан-Широкие поля, Лагерь Тордага: 45.7S, 72.1W";
                };
            };
            Quest4 = {
                Name = {
                    [en] = "Woodhurst Has Fallen";
                    [de] = "Holzmühle ist gefallen";
                    [fr] = "Tertrebois est tombé";
                    [ru] = "Падение Вудгерста";
                };
                Bestower = {
                    [en] = "Gifemund, in Woodhurst, Stonedeans: 47.8S, 79.6W";
                    [de] = "Gifemund, in Holzmühle, Felssenke: 47.8S 79.6W";
                    [fr] = "Gifemund, dans tertrebois, Pierreval : 47.8S, 79.6W";
                    [ru] = "Гифемунд, Западный Рохан-Каменные балки, Вудгерст: 47.8S, 79.6W";
                };
            };
            Quest5 = {
                Name = {
                    [en] = "To Helm's Deep";
                    [de] = "Nach Helms Klamm";
                    [fr] = "Vers le gouffre de Helm";
                    [ru] = "В Хельмову Падь";
                };
                Bestower = {
                    [en] = "Gandalf, in Westfold: 56.5S, 90.5W";
                    [de] = "Gandalf, in der Westfold 56.5S 90.5W";
                    [fr] = "Gandalf, dans l'ouestfold : 56.5S, 90.5W";
                    [ru] = "Гэндальф, Западный Рохан-Западная марка: 56.5S, 90.5W";
                };
            };
            Quest6 = {
                Name = {
                    [en] = "A Ruthless End";
                    [de] = "Ein zügeloses Ende";
                    [fr] = "Une fin brutale";
                    [ru] = "В сердце горы";
                };
                Bestower = {
                    [en] = "Arvaethor, at Nimrond in Ringló Vale: 68.8S, 51.8W";
                    [de] = "Arvaethor, bei Nimrond im Ringlótal: 68.8S 51.8W";
                    [fr] = "Arvaethor, à Nimrond dans le val de Ringló : 68.8S, 51.8W";
                    [ru] = "Арваэтор, Центральный Гондор-Долина Рингло, Нимронд: 68.8S, 51.8W";
                };
            };
            Quest7 = {
                Name = {
                    [en] = "Blood for Blood";
                    [de] = "Blut für Blut";
                    [fr] = "Oeil pour Oeil";
                    [ru] = "Кровь за кровь";
                };
                Bestower = {
                    [en] = "Erchar, at Linhir in Dor-en-Ernil: 80.6S, 44.9W";
                    [de] = "Erchar, in Linhir, Dor-en-Ernil: 80.6S 44.9W";
                    [fr] = "Erchar, dans Linhir en Dor-en-Ernil : 80.6S, 44.9W";
                    [ru] = "Эрхар, Центральный Гондор: Дор-эн-Эрнил, Линхир: 80.6S, 44.9W";
                };
            };
            Quest8 = {
                Name = {
                    [en] = "Sons of the Usurper";
                    [de] = "Söhne des Usurpators";
                    [fr] = "Le fils de l'usurpateur";
                    [ru] = "Сыновья Узурпатора";
                };
                Bestower = {
                    [en] = "Erchar, at Linhir in Dor-en-Ernil: 80.6S, 44.9W";
                    [de] = "Erchar, in Linhir, Dor-en-Ernil: 80.6S 44.9W";
                    [fr] = "Erchar, dans Linhir en Dor-en-Ernil : 80.6S, 44.9W";
                    [ru] = "Эрхар, Центральный Гондор: Дор-эн-Эрнил, Линхир: 80.6S, 44.9W";
                };
            };
            Quest9 = {
                Name = {
                    [en] = "Faltharan's Confrontation";
                    [de] = "Faltharans Kampf";
                    [fr] = "La confrontation de Faltharan";
                    [ru] = "Противостояние Фалтарана";
                };
                Bestower = {
                    [en] = "Thandor, at Pelargir: 83.8S, 32.6W";
                    [de] = "Thandor, Pelargir 83.8S 32.6W";
                    [fr] = "Thandor Pelargir 83.8S 32.6W";
                    [ru] = "Тандор, Центральный Гондор-Пеларгир: 83.8S, 32.6W";
                };
            };
            Quest10 = {
                Name = {
                    [en] = "Ashes and Stars, Chapter 4";
                    [de] = "Asche und Sterne Kapitel 4";
                    [fr] = "Cendres et étoiles, chapitre 4";
                    [ru] = "Пепел и звезды, Глава 4";
                };
                Bestower = {
                    [en] = "Mablung, in Osgiliath Culverts: 62.7S, 8.8W";
                    [de] = "Mablung, Tunnel von Osgiliath, Ost Gondor: 62.7S 8.8W";
                    [fr] = "Mablung dans l'Ouest du Gondor - Tunnel d'Osgiliath 62.7S 8.8W";
                    [ru] = "Маблунг, Восточный Гондор: Осгилиат-Стоки Осгилиата: 62.7S 8.8W";
                };
            };
            Quest11 = {
                Name = {
                    [en] = "Volume IV, Book 2, Chapter 9: Even In Darkness";
                    [de] = "Band IV Buch 2 Kapitel 9: Selbst in der Dunkelheit";
                    [fr] = "Volume IV, Livre 2, Chapitre 9 : Même dans les ténèbres";
                    [ru] = "Том 4, Книга 2, глава 9: Даже во мраке";
                };
                Bestower = {
                    [en] = "Aragorn, at the Camp of the Grey Host in Lebennin: 82.6S, 37.5W";
                    [de] = "Aragorn, im Lager der Schatten in Lebennin: 82.6S 37.5W";
                    [fr] = "Aragorn, au camp de l'Armée grise dans le Lebennin : 82.6S, 37.5W";
                    [ru] = "Арагорн, Центральный Гондор-Лебеннин: 82.6S, 37.5W";
                };
            };
            Quest12 = {
                Name = {
                    [en] = "Volume IV, Book 4, Chapter 10: The Defence of Minas Tirith";
                    [de] = "Band IV Buch 4 Kapitel 10: Verteidigung von Minas Tirith";
                    [fr] = "Volume IV, Livre 4, Chapitre 10 : La défense de Minas Tirith";
                    [ru] = "Том 4, Книга 4, глава 10: Оборона Минас Тирита";
                };
                Bestower = {
                    [en] = "Imrahil, in the Soldiers' Tier of Minas Tirith: 58.1N, 19.2E";
                    [de] = "Imrahil, im Soldatenring (2) von Minas Tirith: 58.1N 19.2O";
                    [fr] = "Imrahil, au niveau des soldats dans Minas Tirith : 58.1N, 19.2E";
                    [ru] = "Имрахиль, Осажденный Минас Тирит-ярус Воинов: 58.1N, 19.2E";
                };
            };
            Quest13 = {
                Name = {
                    [en] = "Volume IV, Book 4, Chapter 11: Hammer of the Underworld";
                    [de] = "Band IV Buch 4 Kapitel 11: Der Unterwelthammer";
                    [fr] = "Volume IV, Livre 4, Chapitre 11 : Le marteau du monde d'en dessous";
                    [ru] = "Том 4, Книга 4, глава 11: Молот Преисподней";
                };
                Bestower = {
                    [en] = "Mithrandir, in the Soldiers' Tier of Minas Tirith: 58.2N, 19.1E";
                    [de] = "Mithrandir, im Soldatenring (2) von Minas Tirith: 58.2N 19.1O";
                    [fr] = "Mithrandir, au niveau des soldats dans Minas Tirith : 58.2N, 19.1E";
                    [ru] = "Митрандир, Осажденный Минас Тирит-ярус Воинов: 58.2N, 19.1E";
                };
            };
            Quest14 = {
                Name = {
                    [en] = "Volume IV, Book 8, Chapter 7: Mordor Triumphant";
                    [de] = "Band IV Buch 8 Kapitel 7: Mordor Triumphal";
                    [fr] = "Volume IV, Livre 8, Chapitre 7 : Le Mordor triomphant";
                    [ru] = "Том 4, Книга 8, глава 7: Триумф Мордора";
                };
                Bestower = {
                    [en] = "Aragorn, at the Battle of the Morannon: 35.0S, 3.3W";
                    [de] = "Aragorn, bei der Schlacht am Morannon: 35.3S 3.5W";
                    [fr] = "Aragorn, au sommet de la colline aride est : 35.0S, 3.3W";
                    [ru] = "Арагорн, Гиблые земли-Шлаковые холмы, Битва у Черных Врат: 35.0S, 3.3W";
                };
            };
            Quest15 = {
                Name = {
                    [en] = "Volume IV, Book 9, Chapter 5: The Next Adventure";
                    [de] = "Band IV Buch 9 Kapitel 5: Das nächste Abenteuer";
                    [fr] = "Volume IV, Livre 9, Chapitre 5 : L'aventure continue";
                    [ru] = "Том 4, Книга 9, глава 5: Приключения продолжаются";
                };
                Bestower = {
                    [en] = "Frodo, at Cormallen in North Ithilien: 47.8S, 12.1W";
                    [de] = "Frodo, in Cormallen in Nord Ithilien: 47.8S, 12.1W";
                    [fr] = "Frodo, au champ de Cormallen dans l'Ithilien du Nord : 47.8S, 12.1W";
                    [ru] = "Фродо, Северный Итилиен-Кормаллен: 47.8S, 12.1W";
                };
            };
            Quest16 = {
                Name = {
                    [en] = "Black Book of Mordor, Chapter 4.4: Union of Evil";
                    [de] = "Das Schwarze Buch von Mordor, Kapitel 4.4: Einheit des Bösen";
                    [fr] = "Le Livre Noir du Mordor : Chapitre 4.4 : Union maléfique";
                    [ru] = "Черная Книга Мордора, Глава 4.4: Единение Зла";
                };
                Bestower = {
                    [en] = "Mithrandir, near the Black Gate in the Wastelands: 39.0S, 2.6W";
                    [de] = "Mithrandir, nahe des Schwarzen Tores im Ödland: 39.0S 2.6W";
                    [fr] = "Mithrandir, près de la Porte Noire dans Les Landes Désertiques : 39.0S, 2.6W";
                    [ru] = "Митрандир, Гиблые земли-Кирит Горгор, Черные Врата: 39.0S, 2.6W";
                };
            };
            Quest17 = {
                Name = {
                    [en] = "Black Book of Mordor, Chapter 5.5: The Walls Brought Down";
                    [de] = "Das Schwarze Buch von Mordor, Kapitel 5.5: Eingerissene Wände";
                    [fr] = "Le Livre Noir du Mordor : Chapitre 5.5 : Les murs détruits";
                    [ru] = "Черная Книга Мордора, Глава 5.5: Стены обрушены";
                };
                Bestower = {
                    [en] = "Sigileth, at Dol Guldur in Mirkwood: 14.6S, 43.5W";
                    [de] = "Sigileth, bei Dol Guldur im Düsterwald: 14.6S 43.5W";
                    [fr] = "Sigileth, à Dol Guldur dans La Forêt Noire  : 14.6S, 43.5W";
                    [ru] = "Сигилет, Лихолесье, Дол Гулдур: 14.6S, 43.5W";
                };
            };
            Quest18 = {
                Name = {
                    [en] = "Black Book of Mordor, Chapter 8.7: The First Promise";
                    [de] = "Das Schwarze Buch von Mordor, Kapitel 8.7: Das erste Versprechen";
                    [fr] = "Le Livre Noir du Mordor : Chapitre 8.7 : La première promesse";
                    [ru] = "Черная Книга Мордора, Глава 8.7: Первое обещание";
                };
                Bestower = {
                    [en] = "Bótuz Frostblood, atop Skarháld in Ered Mithrin: 36.0N, 46.4W";
                    [de] = "Bótuz Frostblut, oben in Skarháld in den Ered Mithrin: 36.0N, 46.4W";
                    [fr] = "Bótuz Frostblood, en haut de Skarháld en Ered Mithrin : 36.0N, 46.4W";
                    [ru] = "Ботуз Хладнокровный, Эред Митрин, наверху Скархальда: 36.0N, 46.4W";
                };
            };
            Quest19 = {
                Name = {
                    [en] = "Black Book of Mordor, Chapter 10.7: The Arrival of the Wise";
                    [de] = "Das Schwarze Buch von Mordor, Kapitel 10.7: Die Ankunft der Weisen";
                    [fr] = "Le Livre Noir du Mordor : Chapitre 10.7 : l'arrivée des Sages";
                    [ru] = "Черная Книга Мордора, Глава 10.7: Прибытие Мудрых";
                };
                Bestower = {
                    [en] = "Gandalf at Beorninghús";
                    [de] = "Gandalf im Beorninghús, Täler des Anduin: 13.5N, 53.3W";
                    [fr] = "Gandalf à Beorninghús dans le Val d'Anduin";
                    [ru] = "Гэндальф, Долина Андуина-Беорнингус: 13.5N, 53.3W";
                };
            };
            Quest20 = {
                Name = {
                    [en] = "Black Book of Mordor, Chapter 12.5: The End of the Tale";
                    [de] = "Das Schwarze Buch von Mordor, Kapitel 12.5: Das Ende der Geschichte";
                    [fr] = "Le Livre Noir du Mordor : Chapitre 12.5 : La fin du récit";
                    [ru] = "Черная Книга Мордора, Глава 12.5: Конец истории";
                };
                Bestower = {
                    [en] = "Gandalf at Tol Send in the Vales of Anduin: 2.3N, 58.1W";
                    [de] = "Gandalf, Tol Send, Täler des Anduin: 2.3N, 58.1W";
                    [fr] = "Gandalf à Tol Send dans le Val d'Anduin";
                    [ru] = "Гэндальф, Долина Андуина-Тол Сенд: 2.3N, 58.1W";
                };
            };
            Quest21 = {
                Name = {
                    [en] = "Black Book of Mordor, Chapter 14.5: A Final Escape";
                    [de] = "Das Schwarze Buch von Mordor, Kapitel 14.5: Die letzte Flucht";
                    [fr] = "Le Livre Noir du Mordor : Chapitre 14.5 : L'ultime évasion";
                    [ru] = "Черная Книга Мордора, Глава 14.5: Последний побег";
                };
                Bestower = {
                    [en] = "Culang at Barad Cúron in Minas Morgul: 67.8S, 1.8E";
                    [de] = "Culang, Barad Cúron in Minas Morgul: 67.8S, 1.8O";
                    [fr] = "Culang, Barad Curon, Minas Morgul : 67.8S, 1.8E";
                    [ru] = "Куланг, Минас Моргул, Барад Курон: 67.8S, 1.8E";
                };
            };
            Quest22 = {
                Name = {
                    [en] = "Legacy of Durin & Trials of the Dwarves, Chapter 2.7: A Thirst for Blood";
                    [de] = "Das Vermächtnis von Durins Volk & Die Prüfung der Zwerge, Kapitel 2.7: Ein Durst nach Blut";
                    [fr] = "Heritage de Durin & ēpreuves des Nains : Chapitre 2.7 : Une soif de sang";
                    [ru] = "Наследие Дарина и испытания гномов, Глава 2.7: Жажда крови";
                };
                Bestower = {
                    [en] = "Imák at Limlók in Wells of Langflood: 21.1N, 56.2W";
                    [de] = "Imák, Limlók, Quellen des Langflut: 21.1N, 56.2W";
                    [fr] = "Imák, Limlók, Puits du Long Fleuve: 21.1N, 56.2W";
                    [ru] = "Имак, Истоки Долгой реки, Лимлок: 21.1N, 56.2W";
                };
            };
            Quest23 = {
                Name = {
                    [en] = "Book 1, Chapter 8: The Wedding Banquet";
                    [de] = "Buch 1, Kapitel 8: Das Hochzeitsbankett";
                    [fr] = "Livre 1, Chapitre 8 : Le banquet de mariage";
                    [ru] = "Книга 1, глава 8: Свадебный банкет";
                };
                Bestower = {
                    [en] = "Rodwen in Minas Tirith (Midsummer): 22.5N 55.9W";
                    [de] = "Rodwen, Minas Tirith (Mittsommer): 22.5N 55.9W";
                    [fr] = "Rodwen, Minas Tirith (Solstice d'été): 22.5N 55.9W";
                    [ru] = "Родвен, Минас Тирит(середина лета): 22.5N 55.9W";
                };
            };
            Quest24 = {
                Name = {
                    [en] = "Legacy of Durin & Trials of the Dwarves, Chapter 4.9: The Lord of Gundabad";
                    [de] = "Das Vermächtnis von Durins Volk & Die Prüfung der Zwerge, Kapitel 4.9: Der Fürst von Gundabad";
                    [fr] = "Heritage de Durin & ēpreuves des Nains : Chapitre 4.9 : Le seigneur de Gundabad";
                    [ru] = "Наследие Дарина и испытания гномов, Глава 4.9: Владыка Гундабада";
                };
                Bestower = {
                    [en] = "Bori at Zarkul-sulûn in Elderslade: 100.9S, 17.3W";
                    [de] = "Bori, Zarkul-sulûn, Ältestental: 100.9S, 17.3W";
                    [fr] = "Bori, Zarkul-sulûn, Val-d'Aïeul : 100.9S, 17.3W";
                    [ru] = "Бори, Долина предков, Заркул-Сулун: 100.9S, 17.3W";
                };
            };
            Quest25 = {
                Name = {
                    [en] = "Interlude: Blood of Azog";
                    [de] = "Zwischenspiel: Azogs Blut";
                    [fr] = "Interlude : Sang d'Azog";
                    [ru] = "Интермедия: Кровь Азога";
                };
                Bestower = {
                    [en] = "Glóin at Annâk-khurfu in Elderslade: 32.8N, 61.2W";
                    [de] = "Glóin, Annâk-khurfu, Ältestental: 32.8N, 61.2W";
                    [fr] = "Gloïn, Annâk-khurfu, Val-d'Aïeul : 32.8N, 61.2W";
                    [ru] = "Глоин, Долина предков, Аннак-Курфу: 32.8N, 61.2W";
                };
            };
            Quest26 = {
                Name = {
                    [en] = "Legacy of Durin and the Trials of the Dwarves, Chapter 7.8: A Silent Presence";
                    [de] = "Das Vermächtnis von Durins Volk & die Prüfung der Zwerge, Kapitel 7.8: Eine stumme Präsenz";
                    [fr] = "L'héritage de Durïn et les épreuves des Nains, Chapitre 7.8 : Une présence silencieuse";
                    [ru] = "Наследие Дарина и испытания гномов, Глава 7.8: Безмолвное присутствие";
                };
                Bestower = {
                    [en] = "Imák in Câr Bronach, Gundabad: 51.5N, 71.4W";
                    [de] = "Imák, Câr Bronach, Gundabad: 51.5N, 71.4W";
                    [fr] = "Imák, Câr Bronach, Gundabad : 51.5N, 71.4W";
                    [ru] = "Имак, Гундабад-Кар Бронах: 51.5N, 71.4W";
                };
            };
            Quest27 = {
                Name = {
                    [en] = "The Legacy of Durin and the Trials of the Dwarves, Chapter 11.5: Gundabad Is Ours!";
                    [de] = "Das Vermächtnis von Durins Volk & die Prüfung der Zwerge, Kapitel 11.5: Gundabad ist unser!";
                    [fr] = "L'héritage de Durïn et les épreuves des Nains, Chapitre 11.5 : Gundabad est à nous !";
                    [ru] = "Наследие Дарина и испытания гномов, Глава 11.5: Гундабад наш!";
                };
                Bestower = {
                    [en] = "Durin, high above Gundabad";
                    [de] = "Durin, hoch über Gundabad";
                    [fr] = "Durin, haut au-dessus de Gundabad";
                    [ru] = "Дарин, Гундабад-Небесная терраса, Вершина над Гундабадом";
                };
            };
        };
        EpicBattles = {
            Help = {
                [en] = "This Class Trait Point is awarded for earning <points> Promotion Points by participating in Epic Battles.  Doing so completes the deed: “Promotion Points <deed>”.  Open your Deed Log, select the “Class/Race/Epic” tab at the top, and the “Class” tab at the bottom.  If the deed is not listed there, you may need to complete an Epic Battle to start it.";
                [de] = "Diesen Klasseneigenschaftpunkt kannst du erhalten, indem du <points> Beförderungspunkte in den Epischen Schlachten erwirbst. Schließe dazu die Tat „Beförderungspunkte <deed>“ ab. Überprüfe wie folgt, ob du dies bereits abgeschlossen hast: Öffne das Buch der Taten, gehe dort auf „Klasse/Rasse/Epos“ und wähle dann unten den Reiter „Klasse“ aus.";
                [fr] = "Ce point de trait de classe est acquis après avoir obtenue <points> points de promotion en participant aux batailles épiques. Cela complête la prouesse : « Points de promotion <deed> ». Ouvrez le journal des prouesses, selectionnez l'onglet « Classe/Race/Epique » ensuite l'onglet « Classe » en bas. Si la prouesse n'apparait pas c'est que vous devez compléter une bataille épique pour la démarrer.";
				[ru] = "1 очко классовых талантов дается за выполнение деяния: “Очки развития <deed>”, за <points> очков развития в битвах. Откройте Журнал деяний, раздел “Класс/раса/эпос” и вкладку “Класс”. Если деяния нет в списке, то Вам необходимо проходить битвы для его получения.";
            };
            Desc = {
                [en] = "For acquiring <points> Promotion Points";
                [de] = "Für <points> Beförderungspunkte (Epische Schlachten)";
				[fr] = "Pour l'acquisition de <points> points de promotion";
				[ru] = "За получение <points> очков развития в битвах";
            };
            Height = {
                [en] = 5;
                [de] = 5;
                [fr] = 6;
                [ru] = 5;
            };
        };
    };
};


-- Add translations to the global database (see Thurallor.Common.Utils.Locale.lua)
L:AddText(text);
